


## How To Use
```bash
poetry install
poetry run sbmodder add https://github.com/cloudflare/hellogopher.git hoge
poetry run sbmodder delete hoge

poetry shell
sbmodder add https://github.com/cloudflare/hellogopher.git hoge
sbmodder delete hoge
```



確認
- サブモジュールに変更があった場合: 強制的に削除される

